@@ -1,6 +1,6 @@
 package Net::DNS::RR::MR;
 
-# $Id: MR.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
+# $Id: MR.pm,v 1.3 2002/05/22 18:09:36 ctriv Exp $
 
 use strict;
 use vars qw(@ISA);
@@ -50,6 +50,17 @@ sub rr_rdata {
 	return $rdata;
 }
 
+sub _canonicalRdata {
+    my $self=shift;
+    my $rdata = "";
+    if (exists $self->{"newname"}) {
+		$rdata .= $self->_name2wire($self->{"newname"});
+	}
+	return $rdata;
+}
+
+
+
 1;
 __END__
 
